## Changelog 🔄
All notable changes to terge will be documented here. This project adheres to [Keep a Changelog](https://keepachangelog.com/en/1.1.0/) and [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.1] - 2024-06-13
### Changed
- Improved the aesthetics of terge's README.
- Ensured that the banner at the top of terge's README links to its GitHub repository.\

## [0.1.0] - 2024-06-12
### Added
- Added the `merge()` function, which merges PyTorch models.

[0.1.0]: https://github.com/umarbutler/terge/releases/tag/v0.1.0